% SIFTSdemo2
%
% DESCRIPTION:
%  Example of computation of Local Spherical Descriptors of a spherical
%  omnidirectional image
%
% VERSION:
%  1.1
%
% AUTHOR:
%  Javier Cruz-Mota, email: javier.cruz@epfl.ch
%  Copyright (C) 2011 EPFL (Ecole Polytechnique Fédérale de Lausanne)
%  Transport and Mobility Laboratoy (TRANSP-OR)
% 
% LICENSE:
%  SIFTS is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%  Please refer to the file COPYING for more information.
%
% REFERENCE:
%  @TECHREPORT{CruzBogdPaquBierThir09,
%     Author = {Javier Cruz-Mota and Iva Bogdanova and Beno{\^\i}t Paquier and Michel Bierlaire and Jean-Philippe Thiran},
%     Institution = {Transport and Mobility Laboratory, Ecole Polytechnique F\'ed\'erale de Lausanne (EPFL)},
%	  Title = {Scale Invariant Feature Transform on the Sphere: Theory and Applications},
%     Year = {2009}
%  }

global SIFTSLocalPath;
% LadyBug2 image:
imageStr = [SIFTSLocalPath '/TestImages/Ladybug2_Image.jpg'];

% Spherical image size
sphSize = 1024;

% Compute the spherical image
ladybugImage = imread(imageStr);
     origImg = LADYBUGToSphere_colour(ladybugImage, sphSize);
      sphImg = double(rgb2gray(origImg));
      sphImg = sphImg - min(min(sphImg));
      sphImg = sphImg/max(max(sphImg));

% Double-size image
% octaveOffset = -1;
% Original-size image
octaveOffset = 0;

% Number of intervals per octave
S = 3;

% Nominal and Base sigmas (in relative distance between pixels)
sigmaN = 0.5;
sigma0 = 3.0;

% Number of stages in the pyramid
numOctaves = floor(log2(sphSize))-5;

% Spherical Scale-Space and DoG computation
 SSS = sphericalScaleSpace(sphImg, S, numOctaves, octaveOffset, sigma0, sigmaN);
SDoG = differenceOfGaussians(SSS);

% Find local maxima/minima in the spherical DoG
[extremePoints, numPoints] = findLocalExtrema(SDoG);

% Compute Local Spherical Descriptors (LSD)
numBinsPrincipalAngle = 36;
              numBins = 8;
  numSpatialDivisions = 4;
 [LSD, extremePoints] = computeLSD(extremePoints, SSS, numBinsPrincipalAngle, numBins, numSpatialDivisions);

% LSD plot
ImgAllStages = drawMarks(origImg, extremePoints);
figure;
yashow(ImgAllStages, 'spheric');
title('[SIFTS] Interest regions and principal orientations of a parabolic image mapped on the sphere');
figure;
yashow(ImgAllStages);
title('[SIFTS] Interest regions and principal orientations of a parabolic image mapped on the sphere (unwrapped)');
 
% Plot of the spherical DoG
figure;
for i = 1:numOctaves-octaveOffset
    for j=1:S+2
        subplot(numOctaves-octaveOffset, S+2, (i-1)*(S+2)+j);
        clims = [-0.15 0.15];
        imagesc(SDoG.octaves(i).octaveContents(j).image, clims);
        axis off;
        colormap gray;
    end
end
suptitle('[SIFTS] Spherical DoG Pyramid');    
   
