function [img] = drawPoint(x, y, img, imgC, imgR, rgb)
% [img] = drawPoint(x, y, img, imgC, imgR, rgb)
%
% DESCRIPTION:
%  Draws a point on an omnidirectional image mapped on the sphere
%
% VERSION:
%  1.1
%
% INPUT:
%  x     =  column
%  y     =  row
%  img   =  omnidirectional image mapped on the sphere
%  imgC  =  number of columns of the spherical image
%  imgR  =  number of rows of the spherical image
%  rgb   =  color to be used (1=red; 2=green; 3=blue; 4=magenta; 5=Cyan;
%           -1=yellow; any other value=white)
%
% OUTPUT:
%  img  =  output image

% AUTHOR:
%  Javier Cruz-Mota, email: javier.cruz@epfl.ch
%  Copyright (C) 2011 EPFL (Ecole Polytechnique Fédérale de Lausanne)
%  Transport and Mobility Laboratoy (TRANSP-OR)
% 
% LICENSE:
%  SIFTS is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%  Please refer to the file COPYING for more information.
%
% REFERENCE:
%  @TECHREPORT{CruzBogdPaquBierThir09,
%     Author = {Javier Cruz-Mota and Iva Bogdanova and Beno{\^\i}t Paquier and Michel Bierlaire and Jean-Philippe Thiran},
%     Institution = {Transport and Mobility Laboratory, Ecole Polytechnique F\'ed\'erale de Lausanne (EPFL)},
%     Title = {Scale Invariant Feature Transform on the Sphere: Theory and Applications},
%     Year = {2009}
%  }

    [yImg,xImg] = returnGoodRowCol(y, x, imgR, imgC);
    
    if(rgb==1)
        img(yImg, xImg, 1) = 255;
        img(yImg, xImg, 2) = 0;
        img(yImg, xImg, 3) = 0;
    elseif(rgb==2)
        img(yImg, xImg, 1) = 0;
        img(yImg, xImg, 2) = 255;
        img(yImg, xImg, 3) = 0;
    elseif(rgb==3)
        img(yImg, xImg, 1) = 0;
        img(yImg, xImg, 2) = 0;
        img(yImg, xImg, 3) = 255;
    elseif(rgb==4)
        img(yImg, xImg, 1) = 255;
        img(yImg, xImg, 2) = 0;
        img(yImg, xImg, 3) = 255;
    elseif(rgb==5)
        img(yImg, xImg, 1) = 0;
        img(yImg, xImg, 2) = 255;
        img(yImg, xImg, 3) = 255;
    elseif(rgb==-1)
        img(yImg, xImg, 1) = 255;
        img(yImg, xImg, 2) = 255;
        img(yImg, xImg, 3) = 0;
    else
        img(yImg, xImg, 1) = 255;
        img(yImg, xImg, 2) = 255;
        img(yImg, xImg, 3) = 255;
    end
end
