function [maskOut] = plotLine(maskIn, samePoints)
% [maskOut] = plotLine(maskIn, samePoints)
%
% DESCRIPTION:
%  Plots lines between the points indicated in samePoints
%
% VERSION:
%  1.1
%
% INPUT:
%  maskIn      =  MxNx3 mask (or image) where the lines will be plotted
%  samePoints  =  list of pairs of points indicating origin and end of
%                 lines
%
% OUTPUT:
%  maskOut  =  output mask (or image)

% AUTHOR:
%  Javier Cruz-Mota, email: javier.cruz@epfl.ch
%  Copyright (C) 2011 EPFL (Ecole Polytechnique Fédérale de Lausanne)
%  Transport and Mobility Laboratoy (TRANSP-OR)
% 
% LICENSE:
%  SIFTS is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%  Please refer to the file COPYING for more information.
%
% REFERENCE:
%  @TECHREPORT{CruzBogdPaquBierThir09,
%     Author = {Javier Cruz-Mota and Iva Bogdanova and Beno{\^\i}t Paquier and Michel Bierlaire and Jean-Philippe Thiran},
%     Institution = {Transport and Mobility Laboratory, Ecole Polytechnique F\'ed\'erale de Lausanne (EPFL)},
%     Title = {Scale Invariant Feature Transform on the Sphere: Theory and Applications},
%     Year = {2009}
%  }

    [imgR, imgC,n] = size(maskIn);
    numPoints = length(samePoints.index1);
    color = 99999;
    maskOut = maskIn;

    for i=1:numPoints
        x1 = samePoints.point1(i,2);
        y1 = samePoints.point1(i,1);
        x2 = samePoints.point2(i,2);
        y2 = samePoints.point2(i,1);
        if(abs(x2+imgC-x1)<abs(x2-x1))
            x2 = x2 + imgC;
        elseif(abs(x2-imgC-x1)<abs(x2-x1))
            x2 = x2 - imgC;
        end
        maskOut = drawPoint(x1, y1, maskOut, imgC, imgR, color);
        if(x1>=x2 && y1>=y2)
            sector = 1;
        elseif(x1>=x2 && y1<y2)
            sector = 2;
        elseif(x1<x2 && y1>=y2)
            sector = 3;
        else
            sector = 4;
        end

        while(x1-x2~=0 || y1-y2~=0)

            if(sector == 1)
                P = [x1-1, y1; x1-1, y1-1; x1, y1-1];
            elseif(sector == 2)
                P = [x1-1, y1; x1-1, y1+1; x1, y1+1];
            elseif(sector == 3)
                P = [x1, y1-1; x1+1, y1-1; x1+1, y1];
            else
                P = [x1+1, y1; x1+1, y1+1; x1, y1+1];
            end
            [val,ind] = min(sqrt((P(:,1)-x2).^2 + (P(:,2)-y2).^2) + sqrt((P(:,1)-samePoints.point1(i,2)).^2 + (P(:,2)-samePoints.point1(i,1)).^2));
            
            x1 = P(ind,1);
            y1 = P(ind,2);
            maskOut = drawPoint(x1, y1, maskOut, imgC, imgR, color);
        end
    end

end
