function showCorrectIncorrectMatchings(samePoints, extremePoints1, extremePoints2, origImg1, origImg2, angle)
% showCorrectIncorrectMatchings(samePoints, extremePoints1, extremePoints2, origImg1, origImg2, angle)
%
% DESCRIPTION:
%  Shows bad matchings in red and correct matchings in green between an
%  omnidirectional image and a rotated version of it.
%
% VERSION:
%  1.1
%
% INPUT:
%  samePoints      =  list of matched points
%  extremePoints1  =  list of extrema of the first image
%  extremePoints2  =  list of extrema of the second image
%  origImg1        =  first image (original image) mapped on the sphere
%  origImg2        =  second image (rotated image) mapped on the sphere
%  angle           =  rotation in radians between the first and the second
%                     image with respect to the x axis

% AUTHOR:
%  Javier Cruz-Mota, email: javier.cruz@epfl.ch
%  Copyright (C) 2011 EPFL (Ecole Polytechnique Fédérale de Lausanne)
%  Transport and Mobility Laboratoy (TRANSP-OR)
% 
% LICENSE:
%  SIFTS is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%  Please refer to the file COPYING for more information.
%
% REFERENCE:
%  @TECHREPORT{CruzBogdPaquBierThir09,
%     Author = {Javier Cruz-Mota and Iva Bogdanova and Beno{\^\i}t Paquier and Michel Bierlaire and Jean-Philippe Thiran},
%     Institution = {Transport and Mobility Laboratory, Ecole Polytechnique F\'ed\'erale de Lausanne (EPFL)},
%     Title = {Scale Invariant Feature Transform on the Sphere: Theory and Applications},
%     Year = {2009}
%  }

    ext1.octave = extremePoints1.octave(samePoints.index1(:));
    ext1.stage = extremePoints1.stage(samePoints.index1(:));
    ext1.sigma = extremePoints1.sigma(samePoints.index1(:));
    ext1.octavePoints = extremePoints1.octavePoints(samePoints.index1(:),:);
    ext1.octaveOptPoints = extremePoints1.octaveOptPoints(samePoints.index1(:),:);
    ext1.imgPoints = extremePoints1.imgPoints(samePoints.index1(:),:);
    ext1.imgOptPoints = extremePoints1.imgOptPoints(samePoints.index1(:),:);
    ext1.gradientAngle = extremePoints1.gradientAngle(samePoints.index1(:));

    ext2.octave = extremePoints2.octave(samePoints.index2(:));
    ext2.stage = extremePoints2.stage(samePoints.index2(:));
    ext2.sigma = extremePoints2.sigma(samePoints.index2(:));
    ext2.octavePoints = extremePoints2.octavePoints(samePoints.index2(:),:);
    ext2.octaveOptPoints = extremePoints2.octaveOptPoints(samePoints.index2(:),:);
    ext2.imgPoints = extremePoints2.imgPoints(samePoints.index2(:),:);
    ext2.imgOptPoints = extremePoints2.imgOptPoints(samePoints.index2(:),:);
    ext2.gradientAngle = extremePoints2.gradientAngle(samePoints.index2(:));

    ImgAllStages1 = origImg1;
    ImgAllStages2 = origImg2;

    [imgR,imgC,n] = size(ImgAllStages1);
    
    ImgTotal(:,:,1)=[ImgAllStages1(:,:,1), 255*ones(imgR,5), ImgAllStages2(:,:,1)];
    ImgTotal(:,:,2)=[ImgAllStages1(:,:,2), 255*ones(imgR,5), ImgAllStages2(:,:,2)];
    ImgTotal(:,:,3)=[ImgAllStages1(:,:,3), 255*ones(imgR,5), ImgAllStages2(:,:,3)];

    [phiGrid, thetaGrid] = sphgrid(imgR, imgC);

    for i=1:length(samePoints.index1)

        coords1 = [ (2*ext1.imgOptPoints(i,1)-1)*pi/(2*imgR), ...
                    (ext1.imgOptPoints(i,2)-1)*2*pi/imgC];
                
        coords2 = [ (2*ext2.imgOptPoints(i,1)-1)*pi/(2*imgR), ...
                    (ext2.imgOptPoints(i,2)-1)*2*pi/imgC];        

        [coords2Theta, coords2Phi] = computeRotatedCoords(coords2(:,1)', coords2(:,2)', pi/2.0, pi, angle); 
        clear coords2;
        coords2 = [diag(coords2Theta),diag(coords2Phi)];
        clear coords2Theta;
        clear coords2Phi;

	if(sphericalDistance(coords1(2), coords2(2), coords1(1), coords2(1)) < 1.5*(ext1.sigma(i)+ext2.sigma(i)) )
	        dist1 = sphericalDistance(coords1(2), phiGrid(:), coords1(1), thetaGrid(:));
	        dist2 = sphericalDistance(coords2(2), phiGrid(:), coords2(1), thetaGrid(:));

        	if(computeOverlapError(dist1, dist2, ext1.sigma(i), ext2.sigma(i)) < 0.5)
	            for j=-3:3
	                for k=-3:3
	                    [r1,c1] = returnGoodRowCol(samePoints.point1(i,1)+j, samePoints.point1(i,2)+k, imgR, imgC);
	                    [r2,c2] = returnGoodRowCol(samePoints.point2(i,1)+j, samePoints.point2(i,2)+k, imgR, imgC);
	                    ImgTotal(r1,c1,1)=0;
	                    ImgTotal(r1,c1,2)=255;
	                    ImgTotal(r1,c1,3)=0;
	                    ImgTotal(r2,c2+5+imgC,1)=0;
	                    ImgTotal(r2,c2+5+imgC,2)=255;
	                    ImgTotal(r2,c2+5+imgC,3)=0;    
	                end
	            end
		else
	            for j=-3:3
	                for k=-3:3
	                    [r1,c1] = returnGoodRowCol(samePoints.point1(i,1)+j, samePoints.point1(i,2)+k, imgR, imgC);
	                    [r2,c2] = returnGoodRowCol(samePoints.point2(i,1)+j, samePoints.point2(i,2)+k, imgR, imgC);
	                    ImgTotal(r1,c1,1)=255;
	                    ImgTotal(r1,c1,2)=0;
	                    ImgTotal(r1,c1,3)=0;
	                    ImgTotal(r2,c2+5+imgC,1)=255;
	                    ImgTotal(r2,c2+5+imgC,2)=0;
	                    ImgTotal(r2,c2+5+imgC,3)=0;    
	                end
	            end
		end
        end
    end
    figure;imshow(ImgTotal);
end
