function showMatchings(samePoints, extremePoints1, extremePoints2, origImg1, origImg2)
% showMatchings(samePoints, extremePoints1, extremePoints2, origImg1, origImg2)
%
% DESCRIPTION:
%  Shows matchings between two omnidirectional images mapped on the sphere
%
% VERSION:
%  1.1
%
% INPUT:
%  samePoints      =  list of matched points
%  extremePoints1  =  list of extrema of the first image
%  extremePoints2  =  list of extrema of the second image
%  origImg1        =  first image mapped on the sphere
%  origImg2        =  second image mapped on the sphere

% AUTHOR:
%  Javier Cruz-Mota, email: javier.cruz@epfl.ch
%  Copyright (C) 2011 EPFL (Ecole Polytechnique Fédérale de Lausanne)
%  Transport and Mobility Laboratoy (TRANSP-OR)
% 
% LICENSE:
%  SIFTS is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%  Please refer to the file COPYING for more information.
%
% REFERENCE:
%  @TECHREPORT{CruzBogdPaquBierThir09,
%     Author = {Javier Cruz-Mota and Iva Bogdanova and Beno{\^\i}t Paquier and Michel Bierlaire and Jean-Philippe Thiran},
%     Institution = {Transport and Mobility Laboratory, Ecole Polytechnique F\'ed\'erale de Lausanne (EPFL)},
%     Title = {Scale Invariant Feature Transform on the Sphere: Theory and Applications},
%     Year = {2009}
%  }
   
    ext1.octave = extremePoints1.octave(samePoints.index1(:));
    ext1.stage = extremePoints1.stage(samePoints.index1(:));
    ext1.sigma = extremePoints1.sigma(samePoints.index1(:));
    ext1.octavePoints = extremePoints1.octavePoints(samePoints.index1(:),:);
    ext1.octaveOptPoints = extremePoints1.octaveOptPoints(samePoints.index1(:),:);
    ext1.imgPoints = extremePoints1.imgPoints(samePoints.index1(:),:);
    ext1.imgOptPoints = extremePoints1.imgOptPoints(samePoints.index1(:),:);
    ext1.gradientAngle = extremePoints1.gradientAngle(samePoints.index1(:));

    ext2.octave = extremePoints2.octave(samePoints.index2(:));
    ext2.stage = extremePoints2.stage(samePoints.index2(:));
    ext2.sigma = extremePoints2.sigma(samePoints.index2(:));
    ext2.octavePoints = extremePoints2.octavePoints(samePoints.index2(:),:);
    ext2.octaveOptPoints = extremePoints2.octaveOptPoints(samePoints.index2(:),:);
    ext2.imgPoints = extremePoints2.imgPoints(samePoints.index2(:),:);
    ext2.imgOptPoints = extremePoints2.imgOptPoints(samePoints.index2(:),:);
    ext2.gradientAngle = extremePoints2.gradientAngle(samePoints.index2(:));

    ImgAllStages1 = drawMarks(origImg1, ext1);
    ImgAllStages2 = drawMarks(origImg2, ext2);

    [imgR,imgC,n] = size(ImgAllStages1);
    
    ImgTotal(:,:,1)=[ImgAllStages1(:,:,1), 255*ones(imgR,5), ImgAllStages2(:,:,1)];
    ImgTotal(:,:,2)=[ImgAllStages1(:,:,2), 255*ones(imgR,5), ImgAllStages2(:,:,2)];
    ImgTotal(:,:,3)=[ImgAllStages1(:,:,3), 255*ones(imgR,5), ImgAllStages2(:,:,3)];

    
    for i=1:length(samePoints.index1)
        for j=-2:2
            for k=-2:2
                [r1,c1] = returnGoodRowCol(ext1.imgPoints(i,1)+j, ext1.imgPoints(i,2)+k, imgR, imgC);
                [r2,c2] = returnGoodRowCol(ext2.imgPoints(i,1)+j, ext2.imgPoints(i,2)+k, imgR, imgC);
                ImgTotal(r1,c1,1)=0;
                ImgTotal(r1,c1,2)=255;
                ImgTotal(r1,c1,3)=0;
                ImgTotal(r2,c2+5+imgC,1)=0;
                ImgTotal(r2,c2+5+imgC,2)=255;
                ImgTotal(r2,c2+5+imgC,3)=0;    
            end
        end
    end

    figure;imshow(ImgTotal);
    for i=1:length(samePoints.index1)
            imline(gca,[samePoints.point1(i,2), imgC+5+samePoints.point2(i,2)],...
                       [samePoints.point1(i,1), samePoints.point2(i,1)]);
    end
    
end
