function showMatchings1by1(samePoints, extremePoints1, extremePoints2, origImg1, origImg2)
% showMatchings1by1(samePoints, extremePoints1, extremePoints2, origImg1, origImg2)
%
% DESCRIPTION:
%  Shows matchings one by one between two omnidirectional images mapped on 
%  the sphere. Left click to show next matching, right click to show
%  previous matching and central click to finish.
%
% VERSION:
%  1.1
%
% INPUT:
%  samePoints      =  list of matched points
%  extremePoints1  =  list of extrema of the first image
%  extremePoints2  =  list of extrema of the second image
%  origImg1        =  first image mapped on the sphere
%  origImg2        =  second image mapped on the sphere

% AUTHOR:
%  Javier Cruz-Mota, email: javier.cruz@epfl.ch
%  Copyright (C) 2011 EPFL (Ecole Polytechnique Fédérale de Lausanne)
%  Transport and Mobility Laboratoy (TRANSP-OR)
% 
% LICENSE:
%  SIFTS is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%  Please refer to the file COPYING for more information.
%
% REFERENCE:
%  @TECHREPORT{CruzBogdPaquBierThir09,
%     Author = {Javier Cruz-Mota and Iva Bogdanova and Beno{\^\i}t Paquier and Michel Bierlaire and Jean-Philippe Thiran},
%     Institution = {Transport and Mobility Laboratory, Ecole Polytechnique F\'ed\'erale de Lausanne (EPFL)},
%     Title = {Scale Invariant Feature Transform on the Sphere: Theory and Applications},
%     Year = {2009}
%  }

    disp('[SIFTS] Showing matchings one by one...');
    msg = sprintf('[SIFTS]\t Left click = next point');
    disp(msg);
    msg = sprintf('[SIFTS]\t Central click = finish');
    disp(msg);
    msg = sprintf('[SIFTS]\t Right click = previous point');
    disp(msg);

    figure;
    numSame=length(samePoints.index1);

    i=1;

    while (i<=numSame)

        ext1.octave = extremePoints1.octave(samePoints.index1(i));
        ext1.stage = extremePoints1.stage(samePoints.index1(i));
        ext1.sigma = extremePoints1.sigma(samePoints.index1(i));
        ext1.octavePoints = extremePoints1.octavePoints(samePoints.index1(i),:);
        ext1.octaveOptPoints = extremePoints1.octaveOptPoints(samePoints.index1(i),:);
        ext1.imgPoints = extremePoints1.imgPoints(samePoints.index1(i),:);
        ext1.imgOptPoints = extremePoints1.imgOptPoints(samePoints.index1(i),:);
        ext1.gradientAngle = extremePoints1.gradientAngle(samePoints.index1(i));

        ext2.octave = extremePoints2.octave(samePoints.index2(i));
        ext2.stage = extremePoints2.stage(samePoints.index2(i));
        ext2.sigma = extremePoints2.sigma(samePoints.index2(i));
        ext2.octavePoints = extremePoints2.octavePoints(samePoints.index2(i),:);
        ext2.octaveOptPoints = extremePoints2.octaveOptPoints(samePoints.index2(i),:);
        ext2.imgPoints = extremePoints2.imgPoints(samePoints.index2(i),:);
        ext2.imgOptPoints = extremePoints2.imgOptPoints(samePoints.index2(i),:);
        ext2.gradientAngle = extremePoints2.gradientAngle(samePoints.index2(i));

        titleStr = ['Point ' num2str(i) ' of ' num2str(numSame)];

        ImgAllStages1 = drawMarks(origImg1, ext1);
        subplot(1, 2, 1);
        imagesc(ImgAllStages1);
        title(titleStr);

        ImgAllStages2 = drawMarks(origImg2, ext2);
        subplot(1, 2, 2);
        imagesc(ImgAllStages2);
        title(titleStr);

        [x,y,button] = ginput(1);
        if (button==3)
            i = i-1;
            if (i<1)
                i=1;
            end
        elseif(button==2)
            i=numSame+1;
        else
            i = i+1;
        end
    end
    disp('[SIFTS] Done!');

end
