function [Theta, k] = estimateTransform(X, s)
% [Theta, k] = estimateTransform(X, s)
%
% DESCRIPTION:
%  Estimates the transform. Inputs and outputs are managed by the RANSAC 
%  toolbox (see its documentation for further details).
%
% VERSION:
%  1.1
%

% AUTHOR:
%  Javier Cruz-Mota, email: javier.cruz@epfl.ch
%  Copyright (C) 2011 EPFL (Ecole Polytechnique Fédérale de Lausanne)
%  Transport and Mobility Laboratoy (TRANSP-OR)
% 
% LICENSE:
%  SIFTS is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%  Please refer to the file COPYING for more information.
%
% REFERENCE:
%  @TECHREPORT{CruzBogdPaquBierThir09,
%     Author = {Javier Cruz-Mota and Iva Bogdanova and Beno{\^\i}t Paquier and Michel Bierlaire and Jean-Philippe Thiran},
%     Institution = {Transport and Mobility Laboratory, Ecole Polytechnique F\'ed\'erale de Lausanne (EPFL)},
%     Title = {Scale Invariant Feature Transform on the Sphere: Theory and Applications},
%     Year = {2009}
%  }

    k=5;
    if ((nargin == 0) || isempty(X))
        Theta = [];
        return
    end

    if ((nargin == 2) && ~isempty(s))
        X = X(:, s);
    end

    N = size(X, 2);
    if (N < k)
        error('estimate_homography:inputError', ...
            'A minimum of 5 point correspondences has been fixed!');
    end

    a = [];
    for i=1:N
        a(3*(i-1)+1,:) = [0,0,0,-X(6,i)*X(1,i),-X(6,i)*X(2,i),-X(6,i)*X(3,i),X(5,i)*X(1,i),X(5,i)*X(2,i),X(5,i)*X(3,i)];
        a(3*(i-1)+2,:) = [X(6,i)*X(1,i),X(6,i)*X(2,i),X(6,i)*X(3,i),0,0,0,-X(4,i)*X(1,i),-X(4,i)*X(2,i),-X(4,i)*X(3,i)];
        a(3*(i-1)+3,:) = [-X(5,i)*X(1,i),-X(5,i)*X(2,i),-X(5,i)*X(3,i),X(4,i)*X(1,i),X(4,i)*X(2,i),X(4,i)*X(3,i),0,0,0];
    end

    [U,S,V] = svd(a);

    Theta = V(:,end);
    
    H = [Theta(1:3)';Theta(4:6)';Theta(7:9)'];
    
    numDiffSign = 0;
    for i=1:N
        xTest = H*X(1:3,i);
        sTest = sign(xTest);
        sP = sign(X(4:6,i));
        if (sTest(1)~=sP(1) && sTest(2)~=sP(2) && sTest(3)~=sP(3))
            numDiffSign = numDiffSign+1;
        end
    end
    
    if (numDiffSign>N/2)
        Theta = -Theta;
    end
end
