function flag = validateTransform(X, Theta, s)
% flag = validateTransform(X, Theta, s)
%
% DESCRIPTION:
%  Checks if the matrix of the computed transformation is ill-conditioned.
%  Inputs and outputs are managed by the RANSAC toolbox (see its 
%  documentation for further details).
%
% VERSION:
%  1.1
%

% AUTHOR:
%  Javier Cruz-Mota, email: javier.cruz@epfl.ch
%  Copyright (C) 2011 EPFL (Ecole Polytechnique Fédérale de Lausanne)
%  Transport and Mobility Laboratoy (TRANSP-OR)
% 
% LICENSE:
%  SIFTS is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%  Please refer to the file COPYING for more information.
%
% REFERENCE:
%  @TECHREPORT{CruzBogdPaquBierThir09,
%     Author = {Javier Cruz-Mota and Iva Bogdanova and Beno{\^\i}t Paquier and Michel Bierlaire and Jean-Philippe Thiran},
%     Institution = {Transport and Mobility Laboratory, Ecole Polytechnique F\'ed\'erale de Lausanne (EPFL)},
%     Title = {Scale Invariant Feature Transform on the Sphere: Theory and Applications},
%     Year = {2009}
%  }

    T_K = 1e6;
    H = [Theta(1:3)';Theta(4:6)';Theta(7:9)'];
    K = cond(H);
    if (K > T_K)
        flag = false;
    else
        flag = true;
    end
end
