function [sphericalImage] = LADYBUGToSphere_colour(ladybugImage, sphSize)
% [sphericalImage] = LADYBUGToSphere_colour(ladybugImage, sphSize)
%
% DESCRIPTION:
%  Adapts an spherical image captured with a Ladybug2 device to a NxN
%  spherical grid
%
% VERSION:
%  1.1
%
% INPUT:
%  ladybugImage  =  original spherical image
%  sphSize       =  desired size of the spherical grid. Must be a power of 
%                   2, for example 1024
%
% OUTPUT:
%  sphericalImage  =  output spherical image

% AUTHOR:
%  Javier Cruz-Mota, email: javier.cruz@epfl.ch
%  Copyright (C) 2011 EPFL (Ecole Polytechnique Fédérale de Lausanne)
%  Transport and Mobility Laboratoy (TRANSP-OR)
% 
% LICENSE:
%  SIFTS is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%  Please refer to the file COPYING for more information.
%
% REFERENCE:
%  @TECHREPORT{CruzBogdPaquBierThir09,
%     Author = {Javier Cruz-Mota and Iva Bogdanova and Beno{\^\i}t Paquier and Michel Bierlaire and Jean-Philippe Thiran},
%     Institution = {Transport and Mobility Laboratory, Ecole Polytechnique F\'ed\'erale de Lausanne (EPFL)},
%     Title = {Scale Invariant Feature Transform on the Sphere: Theory and Applications},
%     Year = {2009}
%  }

    tic
    disp('[SIFTS] Mapping spherical image on a squared spherical grid...');

    [M,N,c] = size(ladybugImage);
    sphericalImage = imresize(ladybugImage, [sphSize sphSize]);
    
    disp('[SIFTS] Done!');
    t=toc;
    disp(sprintf('[SIFTS] Computation time: %f seconds\n',t));    
end
