function overlapError = computeOverlapError(dist1, dist2, sigma1, sigma2)
% overlapError = computeOverlapError(dist1, dist2, sigma1, sigma2)
%
% DESCRIPTION:
%  Computes the overlap error (Mikolajczyk et al(2005), "A comparison of 
%  affine region detectors", International Journal of Computer Vision, 
%  Vol. 65).
%
% VERSION:
%  1.1
%
% INPUT:
%  dist1   =  Distance map to the first point
%  dist2   =  Distance map to the second point
%  sigma1  =  Scale of the first point
%  sigma2  =  Scale of the second point
%
% OUTPUT:
%  overlapError  =  Value of the overlap error, considering regions
%                   of size 1.5*sigma

% AUTHOR:
%  Javier Cruz-Mota, email: javier.cruz@epfl.ch
%  Copyright (C) 2011 EPFL (Ecole Polytechnique Fédérale de Lausanne)
%  Transport and Mobility Laboratoy (TRANSP-OR)
% 
% LICENSE:
%  SIFTS is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%  Please refer to the file COPYING for more information.
%
% REFERENCE:
%  @TECHREPORT{CruzBogdPaquBierThir09,
%     Author = {Javier Cruz-Mota and Iva Bogdanova and Beno{\^\i}t Paquier and Michel Bierlaire and Jean-Philippe Thiran},
%     Institution = {Transport and Mobility Laboratory, Ecole Polytechnique F\'ed\'erale de Lausanne (EPFL)},
%     Title = {Scale Invariant Feature Transform on the Sphere: Theory and Applications},
%     Year = {2009}
%  }

    ind1 = find(dist1<=1.5*sigma1);
    ind2 = find(dist2<=1.5*sigma2);
    
    inter = intersect(ind1, ind2);
    
    uni = union(ind1, ind2);
    overlapError = 1-length(inter)/length(uni);
end
