function [newCol] = returnGoodCol(oldCol, numCols)
% [newCol] = returnGoodCol(oldCol, numCols)
%
% DESCRIPTION:
%  Returns the equivalent column number in the spherical grid.
%
% VERSION:
%  1.1
%
% INPUT:
%  oldCol   =  column number
%  numCols  =  number of columns of the spherical grid
%
% OUTPUT:
%  newCol  =  column number in the interval [1,numCols]

% AUTHOR:
%  Javier Cruz-Mota, email: javier.cruz@epfl.ch
%  Copyright (C) 2011 EPFL (Ecole Polytechnique Fédérale de Lausanne)
%  Transport and Mobility Laboratoy (TRANSP-OR)
% 
% LICENSE:
%  SIFTS is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%  Please refer to the file COPYING for more information.
%
% REFERENCE:
%  @TECHREPORT{CruzBogdPaquBierThir09,
%     Author = {Javier Cruz-Mota and Iva Bogdanova and Beno{\^\i}t Paquier and Michel Bierlaire and Jean-Philippe Thiran},
%     Institution = {Transport and Mobility Laboratory, Ecole Polytechnique F\'ed\'erale de Lausanne (EPFL)},
%     Title = {Scale Invariant Feature Transform on the Sphere: Theory and Applications},
%     Year = {2009}
%  }

    newCol = oldCol;
     
    while(any(newCol(:)<1))
        newCol(newCol<1) = newCol(newCol<1) + numCols;
    end
    
    while(any(newCol(:)>numCols))
        newCol(newCol>numCols) = newCol(newCol>numCols) - numCols;
    end
end
