function [newRow,newCol] = returnGoodRowCol(oldRow, oldCol, numRows, numCols)
% [newRow,newCol] = returnGoodRowCol(oldRow, oldCol, numRows, numCols)
%
% DESCRIPTION:
%  Returns the equivalent column and row number in the spherical grid. At 
%  the poles, we consider that the first/last row is replicated. It is 
%  assumed that the amount of pixels outside [1,number of rows] is less 
%  than the number of rows
%
% VERSION:
%  1.1
%
% INPUT:
%  oldRow   =  row number
%  oldCol   =  column number
%  numRows  =  number of rows of the spherical grid
%  numCols  =  number of columns of the spherical grid
%
% OUTPUT:
%  newRow  =  row number in the interval [1,numRows]
%  newCol  =  column number in the interval [1,numCols]

% AUTHOR:
%  Javier Cruz-Mota, email: javier.cruz@epfl.ch
%  Copyright (C) 2011 EPFL (Ecole Polytechnique Fédérale de Lausanne)
%  Transport and Mobility Laboratoy (TRANSP-OR)
% 
% LICENSE:
%  SIFTS is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%  Please refer to the file COPYING for more information.
%
% REFERENCE:
%  @TECHREPORT{CruzBogdPaquBierThir09,
%     Author = {Javier Cruz-Mota and Iva Bogdanova and Beno{\^\i}t Paquier and Michel Bierlaire and Jean-Philippe Thiran},
%     Institution = {Transport and Mobility Laboratory, Ecole Polytechnique F\'ed\'erale de Lausanne (EPFL)},
%     Title = {Scale Invariant Feature Transform on the Sphere: Theory and Applications},
%     Year = {2009}
%  }

    newCol = returnGoodCol(oldCol, numCols);

    newRow = oldRow;
   
    if (any(newRow(:) > numRows) || any(newRow(:) < 1))
        
        rowInds = find(newRow<0);
        newRow = abs(newRow);
        newRow(newRow<1) = 1;
        newCol(rowInds) = newCol(rowInds)+numCols/2;
        
        rowInds = find(newRow>numRows+1);
        newRow(newRow>numRows+1) = 2*numRows+2-newRow(newRow>numRows+1);
        newRow(newRow>numRows) = numRows;
        newCol(rowInds) = newCol(rowInds)+numCols/2;

        newCol = returnGoodCol(newCol, numCols);
    end

end
